'use strict';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const lodash_clone_1 = __importDefault(require("lodash.clone"));
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const metadata_object_1 = __importDefault(require("./metadata.object"));
class EvaluationRecord {
    constructor(evaluator) {
        this.type = 'evaluation';
        this.evaluator = lodash_clone_1.default(evaluator);
        this.metadata = new metadata_object_1.default();
        this.modules = {};
    }
    addModuleEvaluation(module, evaluation) {
        this.modules[module] = lodash_clonedeep_1.default(evaluation);
        if (module !== 'wappalyzer') {
            this.metadata.addPassedResults(this.modules[module].metadata.passed || 0);
            this.metadata.addWarningResults(this.modules[module].metadata.warning || 0);
            this.metadata.addFailedResults(this.modules[module].metadata.failed || 0);
            this.metadata.addInapplicableResults(this.modules[module].metadata.inapplicable || 0);
        }
    }
    getFinalReport() {
        return lodash_clonedeep_1.default({
            type: this.type,
            system: this.evaluator,
            metadata: this.metadata.getResults(),
            modules: this.modules
        });
    }
}
module.exports = EvaluationRecord;
